@@ -198,3 +198,36 @@ varplot <- function(x, ...){
   ada::varplot(x, ...)
 }
 
+#' dummy.data.frame
+#'
+#' function from dummies package
+#'
+#' @keywords internal
+#'
+dummy.data.frame <- function (data, names = NULL, omit.constants = TRUE, dummy.classes = getOption("dummy.classes"),
+          all = TRUE, ...)
+{
+  df <- data.frame(row.names = row.names(data))
+  new.attr <- list()
+  for (nm in names(data)) {
+    old.attr <- attr(df, "dummies")
+    if (nm %in% names || (is.null(names) && (dummy.classes ==
+                                             "ALL" || class(data[, nm]) %in% dummy.classes))) {
+      dummies <- dummy(nm, data, ...)
+      if (ncol(dummies) == 1 & omit.constants) {
+        dummies <- matrix(nrow = nrow(data), ncol = 0)
+      }
+      if (ncol(dummies) > 0)
+        new.attr[[nm]] <- (ncol(df) + 1):(ncol(df) +
+                                            ncol(dummies))
+    }
+    else {
+      if (!all)
+        (next)()
+      dummies <- data[, nm, drop = FALSE]
+    }
+    df <- cbind(df, dummies)
+  }
+  attr(df, "dummies") <- new.attr
+  return(df)
+}
